@@ -223,12 +223,12 @@ and alternative commands."
   (magit-with-toplevel
     (let* ((dir   (magit-gitdir))
            (revA  (or (magit-name-branch "HEAD")
-                      (magit-commit-p "HEAD")))
+                      (magit-commit-oid "HEAD")))
            (revB  (cl-find-if (##file-exists-p (expand-file-name % dir))
                               '("MERGE_HEAD" "CHERRY_PICK_HEAD" "REVERT_HEAD")))
            (revB  (or (magit-name-branch revB)
-                      (magit-commit-p revB)))
-           (revC  (magit-commit-p (magit-git-string "merge-base" revA revB)))
+                      (magit-commit-oid revB)))
+           (revC  (magit-commit-oid (magit-git-string "merge-base" revA revB)))
            (fileA (magit--rev-file-name file revA revB))
            (fileB (magit--rev-file-name file revB revA))
            (fileC (or (magit--rev-file-name file revC revA)
